@@ -52,9 +52,9 @@ class WorldSceneAxes: public QGraphicsItem
 {
 public:
     WorldSceneAxes(QGraphicsItem* parent = 0, QGraphicsScene* scene = 0);
-    QRectF boundingRect() const Q_DECL_OVERRIDE;
-    QPainterPath shape() const Q_DECL_OVERRIDE;
-    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) Q_DECL_OVERRIDE;
+    QRectF boundingRect() const override;
+    QPainterPath shape() const override;
+    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) override;
     void viewScaleChanged();
 
 protected:
